==> Botan-1.1.3.tgz: Botan-1.1.3/include/pbe_pkcs.h <==
/*************************************************
* PKCS PBE Header File                           *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_PBE_PKCS_H__
#define BOTAN_PBE_PKCS_H__

#include <botan/filters.h>

namespace Botan {

/*************************************************
* PKCS PBE Base                                  *
*************************************************/
class PBE_PKCS : public PBE
   {
   public:
      void write(const byte[], u32bit);
      void start_msg();
      void end_msg();
   protected:
      PBE_PKCS(const std::string&, const std::string&, Cipher_Dir);
      void new_params();
      SecureVector<byte> salt;
      u32bit iterations;
   private:
      void set_key(const std::string&);
      void flush_pipe(bool);
      virtual std::string name() const = 0;
      virtual std::string pbkdf_name() const = 0;
      virtual u32bit keylength_for(const std::string&) const = 0;
      std::string digest, cipher;
      Keyed_Filter* cipher_obj;
      Pipe pipe;
      SecureVector<byte> key, iv;
      bool key_set;
   };

/*************************************************
* PKCS#5 v1.5 PBE                                *
*************************************************/
class PBE_PKCS5v15 : public PBE
   {
   public:
      void write(const byte[], u32bit);
      void start_msg();
      void end_msg();
      PBE_PKCS5v15(const std::string&, const std::string&, Cipher_Dir);
   private:
      void set_key(const std::string&);
      void new_params();
      SecureVector<byte> encode_params() const;
      void decode_params(DataSource&);
      OID get_oid() const;
      void flush_pipe(bool);
      const Cipher_Dir direction;
      std::string digest, cipher;
      Keyed_Filter* cipher_obj;
      Pipe pipe;
      SecureVector<byte> salt, key, iv;
      u32bit iterations;
      bool key_set;
   };

/*************************************************
* PKCS#5 v2.0 PBE                                *
*************************************************/
class PBE_PKCS5v20 : public PBE
   {
   public:
      void write(const byte[], u32bit);
      void start_msg();
      void end_msg();
      PBE_PKCS5v20(const std::string&, const std::string&, Cipher_Dir);
   private:
      void set_key(const std::string&);
      void new_params();
      SecureVector<byte> encode_params() const;
      void decode_params(DataSource&);
      OID get_oid() const;
      void flush_pipe(bool);
      const Cipher_Dir direction;
      std::string digest, cipher;
      Keyed_Filter* cipher_obj;
      Pipe pipe;
      SecureVector<byte> salt, key, iv;
      u32bit iterations, key_length;
      bool key_set;
   };

}

#endif

==> Botan-1.1.5.tgz: Botan-1.1.5/include/pbe_pkcs.h <==
/*************************************************
* PKCS PBE Header File                           *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_PBE_PKCS_H__
#define BOTAN_PBE_PKCS_H__

#include <botan/filters.h>

namespace Botan {

/*************************************************
* PKCS#5 v1.5 PBE                                *
*************************************************/
class PBE_PKCS5v15 : public PBE
   {
   public:
      void write(const byte[], u32bit);
      void start_msg();
      void end_msg();
      PBE_PKCS5v15(const std::string&, const std::string&, Cipher_Dir);
   private:
      void set_key(const std::string&);
      void new_params();
      SecureVector<byte> encode_params() const;
      void decode_params(DataSource&);
      OID get_oid() const;
      void flush_pipe(bool);
      std::string digest, cipher;
      Keyed_Filter* cipher_obj;
      Pipe pipe;
      SecureVector<byte> salt, key, iv;
      u32bit iterations;
   };

/*************************************************
* PKCS#5 v2.0 PBE                                *
*************************************************/
class PBE_PKCS5v20 : public PBE
   {
   public:
      void write(const byte[], u32bit);
      void start_msg();
      void end_msg();
      PBE_PKCS5v20(DataSource&);
      PBE_PKCS5v20(const std::string&, const std::string&);
   private:
      void set_key(const std::string&);
      void new_params();
      SecureVector<byte> encode_params() const;
      void decode_params(DataSource&);
      OID get_oid() const;
      void flush_pipe(bool);
      std::string digest, cipher;
      Keyed_Filter* cipher_obj;
      Pipe pipe;
      SecureVector<byte> salt, key, iv;
      u32bit iterations, key_length;
   };

}

#endif
